@@ -3,6 +3,6 @@
 # @Author  : vicissitude
 import timeworker
 
-time_str = '21年11月'
+time_str = '五个月内的'
 print('输入：{}'.format(time_str))
 print('标准化：{}'.format(timeworker.parse(time_str)))
\ No newline at end of file
