@@ -2,7 +2,7 @@ __version__ = '1.1.2'
 
 from .date import DateDataParser
 from .conf import apply_settings
-from .utils.additional import str_preprocess, get_time_again
+from .utils.additional import str_preprocess, strong_rules, get_time_again
 
 _default_parser = DateDataParser()
 
@@ -62,6 +62,9 @@ def parse(date_string, date_formats=None, locales=None,
     date_string = str_preprocess(date_string)
 
     try:
+        data = strong_rules(date_string)
+        if data:
+            return data
         data = parser.get_date_data(date_string, date_formats)
         if data:
             if isinstance(data, list):
