@@ -1,3 +1,8 @@
+# -*- coding: utf-8 -*-
+# @Time    : 2023/2/24 09:37
+# @Author  : vicissitude
+
+
 language_order = [
     "en",
     "ru",
@@ -1349,3 +1354,7 @@ language_locale_dict = {
     "eo": [],
     "tl": []
 }
+
+stopwords = {
+    '的'
+}
\ No newline at end of file
